@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@ KAddressBookPluginInterface::KAddressBookPluginInterface(QObject *parent)
     : PimCommon::PluginInterface(parent)
 {
     setPluginName(QStringLiteral("kaddressbook"));
-    setServiceTypeName(QStringLiteral("KAddressBook/MainViewPlugin"));
+    setPluginDirectory(QStringLiteral("kaddressbook/mainview"));
 }
 
 KAddressBookPluginInterface::~KAddressBookPluginInterface()
@@ -53,7 +53,6 @@ void KAddressBookPluginInterface::initializeInterfaceRequires(PimCommon::Abstrac
         interface->setCurrentItems(mMainWidget->collectSelectedAllContactsItem());
     }
     if (requires & PimCommon::GenericPluginInterface::Items) {
-        qDebug() << " void KAddressBookPluginInterface::initializeInterfaceRequires(PimCommon::AbstractGenericPluginInterface *abstractInterface)";
         interface->setItems(mMainWidget->selectedItems());
     }
     if (requires & PimCommon::GenericPluginInterface::CurrentCollection) {
